==> gm-1.6.3_Linux.tar.gz: gm-1.6.3_Linux/drivers/aix/ip/gmip.h <==
#ifndef _gmip_h_
#define _gmip_h_

#include "gm.h"
#include "gm_internal.h"
#include "gm_ether.h"

#include <sys/cdli.h>
#include <sys/ndd.h>
#include <sys/ethernet_mibs.h>
#include <net/if.h>
#include <net/spl.h>
#include <netinet/if_ether.h>
#include <sys/cdli_entuser.h>

/*
#include "gm_debug_lanai_dma.h"
#include "gm_arch_def.h"
#include "gm_trace.h"
#include "gm_pio.h"
*/

#include "gm_ether.h"

#define GM_ETHER_MAXDMA         (GM_ETHERNET_MTU)
#define GM_SEND_RING_CNT        16      /* MUST be power of 2 */
#define GM_SW_RING_CNT        	16*GM_SEND_RING_CNT
#define GM_RECV_RING_CNT        GM_NUM_ETHERNET_RECV_TOKENS
#define GM_SEND_RING_MAX_INDEX (GM_SEND_RING_CNT -1)
#define GM_SW_RING_MAX_INDEX 	(GM_SW_RING_CNT -1)
#define GM_RECV_RING_MAX_INDEX (GM_RECV_RING_CNT -1)

#define GM_MAX_ETHERNET_SG_CNT (GM_MAX_ETHERNET_SCATTER_CNT > GM_MAX_ETHERNET_GATHER_CNT ? GM_MAX_ETHERNET_SCATTER_CNT : GM_MAX_ETHERNET_GATHER_CNT)

#define DBG(x)
#define DBG_ERR(x) x

extern dd_ctrl_t dd_ctrl;


/* Increment double int counter */
#define INCREMENT_DINT(lsw, msw)	\
	{				\
		if ((lsw) + (ulong)1 == 0)	\
			(msw)++;	\
		(lsw)++;		\
	}

#define ADD_DINT(lsw, msw, add)		\
	{				\
		if ((lsw) + (ulong)(add) < (lsw)) \
			(msw)++;	\
		(lsw) += (add);		\
	}

#define	GM_AIX_IP_INC(x,y)	x = (x + 1) % y


struct gm_aix_ether_arch_dma_info
{
  gm_ethernet_segment_descriptor_t desc[GM_MAX_ETHERNET_SG_CNT];
  //  gm_dp_t dp[GM_MAX_ETHERNET_SG_CNT];
  //  unsigned long paddr[GM_MAX_ETHERNET_SG_CNT];
  struct dio_64		dio;
  struct d_iovec_64   	iovec[GM_MAX_ETHERNET_SG_CNT];
  //  int 			nsegs;
};

struct gm_aix_ether_pkt
{
  struct gm_aix_ether_arch_dma_info dma;
  struct mbuf *m;
  int prepend;
};

struct gm_aix_ether_sc
{  
  dev_ctrl_t *p_dev;				/* AIX Device control */
  struct gm_instance_state *is;                 /* gm instance */
  struct gm_port *port;                         /* gm port */
  struct gm_aix_ether_pkt send_ring[GM_SEND_RING_CNT];  /* pending sends */
  struct gm_aix_ether_pkt sw_ring[GM_SW_RING_CNT];  /* pending queued sends */
  struct gm_aix_ether_pkt recv_ring[GM_RECV_RING_CNT]; /* pending rcvs */
  int sreq;                                     /* #sends requested */
  int sdone;                                    /* #sends completed */
  int sw_req;                                   /* sw #sends requested */
  int sw_done;                                  /* sw #sends completed */
  unsigned rdone;                               /* #receives */
  int open;                                     /* is device open?*/
};




/***********************************************************************
 * Function prototype declarations for shared functions
 ***********************************************************************/

void gm_aix_ether_rxeof (void *ptr, unsigned int ulen, gm_u16_t csum);

void gm_aix_ether_txeof (void *ptr);

int gm_aix_ip_open (ndd_t *the_ndd);

int gm_aix_ip_close (ndd_t *the_ndd);

int gm_aix_ip_output(ndd_t *the_ndd,  struct mbuf *mbuf_head);

int gm_aix_ip_ioctl(
  ndd_t *p_ndd,				/* ndd structure in device control */
  int cmd,				/* ioctl command */
  caddr_t arg,				/* ioctl command argument */
  int length				/* length of argument */
);

struct cdt *cdt_func(void);

#if GM_AIX_SUPPORT_MULTI
void enable_multicast(
  dev_ctrl_t *p_dev                     /* Device control structure ptr */
  );

void disable_multicast(
  dev_ctrl_t *p_dev                     /* Device control structure ptr */
  );
#endif

void enable_promiscuous(
  dev_ctrl_t *p_dev                     /* Device control structure ptr */
  );

void disable_promiscuous(
  dev_ctrl_t *p_dev                     /* Device control structure ptr */
  );

ENT_ADDR_TYPE get_addr_type(
  ENT_PKT *pkt				/* Packet pointer */
  );

struct mbuf * gm_aix_ip_filter_mcast(
  dev_ctrl_t *p_dev,   			/* Device control structure ptr */
  struct mbuf *mbufp
  );

int my_disable_lock (int pri, simple_lock_t lock);
void my_unlock_enable (int pri, simple_lock_t lock);
void gm_aix_ip_clear_offlevel (dev_ctrl_t *p_dev);
void gm_aix_ip_init_offlevel (dev_ctrl_t *p_dev);
void gm_aix_ip_sched_offlevel (dev_ctrl_t *p_dev);


#endif /* _gmip_h_ */

/*
  This file uses GM standard indentation.

  Local Variables:
  c-file-style:"gnu"
  tab-width:8
  End:
*/

==> gm-2.0.8_Linux.tar.gz: gm-2.0.8_Linux/drivers/aix/ip/gmip.h <==
#ifndef _gmip_h_
#define _gmip_h_

#include "gm.h"
#include "gm_internal.h"
#include "gm_ether.h"

/* forward declarations for busted AIX header files */
struct domain_funnel;
struct netopt;
struct mpool_debug;

#include <sys/cdli.h>
#include <sys/ndd.h>
#include <sys/ethernet_mibs.h>
#include <net/if.h>
#include <net/spl.h>
#include <netinet/if_ether.h>
#include <sys/cdli_entuser.h>

/*
#include "gm_debug_lanai_dma.h"
#include "gm_arch_def.h"
#include "gm_trace.h"
#include "gm_pio.h"
*/

#include "gm_ether.h"

#define GM_ETHER_MAXDMA         (GM_ETHERNET_MTU)
#define GM_SEND_RING_CNT        16      /* MUST be power of 2 */
#define GM_SW_RING_CNT        	16*GM_SEND_RING_CNT
#define GM_RECV_RING_CNT        GM_NUM_ETHERNET_RECV_TOKENS
#define GM_SEND_RING_MAX_INDEX (GM_SEND_RING_CNT -1)
#define GM_SW_RING_MAX_INDEX 	(GM_SW_RING_CNT -1)
#define GM_RECV_RING_MAX_INDEX (GM_RECV_RING_CNT -1)

#define GM_MAX_ETHERNET_SG_CNT (GM_MAX_ETHERNET_SCATTER_CNT > GM_MAX_ETHERNET_GATHER_CNT ? GM_MAX_ETHERNET_SCATTER_CNT : GM_MAX_ETHERNET_GATHER_CNT)

#define DBG(x)
#define DBG_ERR(x) x

extern dd_ctrl_t dd_ctrl;


/* Increment double int counter */
#define INCREMENT_DINT(lsw, msw)	\
	{				\
		if ((lsw) + (ulong)1 == 0)	\
			(msw)++;	\
		(lsw)++;		\
	}

#define ADD_DINT(lsw, msw, add)		\
	{				\
		if ((lsw) + (ulong)(add) < (lsw)) \
			(msw)++;	\
		(lsw) += (add);		\
	}

#define	GM_AIX_IP_INC(x,y)	x = (x + 1) % y


struct gm_aix_ether_arch_dma_info
{
  gm_ethernet_segment_descriptor_t desc[GM_MAX_ETHERNET_SG_CNT];
  //  gm_dp_t dp[GM_MAX_ETHERNET_SG_CNT];
  //  unsigned long paddr[GM_MAX_ETHERNET_SG_CNT];
  struct dio_64		dio;
  struct d_iovec_64   	iovec[GM_MAX_ETHERNET_SG_CNT];
  //  int 			nsegs;
};

struct gm_aix_ether_pkt
{
  struct gm_aix_ether_arch_dma_info dma;
  struct mbuf *m;
};

struct gm_aix_ether_sc
{  
  dev_ctrl_t *p_dev;				/* AIX Device control */
  struct d_handle *d_handle;			/* DMA handle */
  struct gm_instance_state *is;                 /* gm instance */
  struct gm_port *port;                         /* gm port */
  struct gm_aix_ether_pkt send_ring[GM_SEND_RING_CNT];  /* pending sends */
  struct gm_aix_ether_pkt sw_ring[GM_SW_RING_CNT];  /* pending queued sends */
  struct gm_aix_ether_pkt recv_ring[GM_RECV_RING_CNT]; /* pending rcvs */
  int sreq;                                     /* #sends requested */
  int sreq_index;
  int sdone;                                    /* #sends completed */
  int sdone_index;
  int sw_req;                                   /* sw #sends requested */
  int sw_done;                                  /* sw #sends completed */
  unsigned rdone;                               /* #receives */
  int open;                                     /* is device open?*/
  struct mbuf *bogus_m;				/* "bogus_m" err handling*/
  struct gm_aix_ether_arch_dma_info bogus_dma;	/* "bogus_dma" err handling*/
  struct gm_aix_ether_arch_dma_info send_dma;	/* xmit dma convenience */
};




/***********************************************************************
 * Function prototype declarations for shared functions
 ***********************************************************************/

void gm_aix_ether_rxeof (void *ptr, gm_ethernet_recv_t *e);

void gm_aix_ether_txeof (void *ptr);

int gm_aix_ip_open (ndd_t *the_ndd);

int gm_aix_ip_close (ndd_t *the_ndd);

int gm_aix_ip_output(ndd_t *the_ndd,  struct mbuf *mbuf_head);

int gm_aix_ip_ioctl(
  ndd_t *p_ndd,				/* ndd structure in device control */
  int cmd,				/* ioctl command */
  caddr_t arg,				/* ioctl command argument */
  int length				/* length of argument */
);

struct cdt *cdt_func(void);

#if GM_AIX_SUPPORT_MULTI
void enable_multicast(
  dev_ctrl_t *p_dev                     /* Device control structure ptr */
  );

void disable_multicast(
  dev_ctrl_t *p_dev                     /* Device control structure ptr */
  );
#endif

void enable_promiscuous(
  dev_ctrl_t *p_dev                     /* Device control structure ptr */
  );

void disable_promiscuous(
  dev_ctrl_t *p_dev                     /* Device control structure ptr */
  );

ENT_ADDR_TYPE get_addr_type(
  ENT_PKT *pkt				/* Packet pointer */
  );

struct mbuf * gm_aix_ip_filter_mcast(
  dev_ctrl_t *p_dev,   			/* Device control structure ptr */
  struct mbuf *mbufp
  );

void gm_aix_ip_clear_offlevel (dev_ctrl_t *p_dev);
void gm_aix_ip_init_offlevel (dev_ctrl_t *p_dev);
void gm_aix_ip_sched_offlevel (dev_ctrl_t *p_dev);


#endif /* _gmip_h_ */

/*
  This file uses GM standard indentation.

  Local Variables:
  c-file-style:"gnu"
  tab-width:8
  End:
*/
